tiled.adapters.xarray.VariableAdapter
=====================================

.. currentmodule:: tiled.adapters.xarray

.. autoclass:: VariableAdapter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~VariableAdapter.__init__
      ~VariableAdapter.macrostructure
      ~VariableAdapter.microstructure
      ~VariableAdapter.read
      ~VariableAdapter.read_block
      ~VariableAdapter.structure
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~VariableAdapter.metadata
      ~VariableAdapter.specs
      ~VariableAdapter.structure_family
   
   